%%
% Replication code for "Understanding HANK: Insights from a PRANK"
% Authors: Sushant Acharya and Keshav Dogra
% February 4, 2020
% Code for model with persistent income case: Plots Figures 4 and 5 in 
% Figure 3 in Appendix

%% Housekeeping 
clear;
clc;
close all;

% Figure 3 a) persistent income case 

% Parameters
param.gam = 3;
param.r = 0.04;
param.mu = param.r/(1+param.r);
param.kap = 0.1; % slope of phillips curve
param.thet = 1; % note, we can always find some dsigdy that generates this
param.sigss = 0.02; 0.1^2;
param.btil = 1-param.mu;
param.babylam = 0.97; % persistence of skill shock
param.lam = param.gam*(param.r/(1+param.r-param.babylam))*param.sigss;
param.truebeta = (1/(1+param.r))*exp(- param.sigss*(param.gam*param.r/(1+param.r-param.babylam))^2);

% make phipi and theta grids
npp = 800;
nth = 200;
ppgrid = linspace(0.5,2,npp);
thgrid = linspace(0.97,1.03,nth);
indet  = zeros(npp,nth);
for ipp = 1:npp
    for ith = 1:nth
        param.thet = thgrid(ith);
        param.phipi = ppgrid(ipp);
        some_eigs = eigs_noniid(param);
        if param.babylam>0
            indet(ipp,ith) = any(abs(some_eigs)<1);
        elseif param.babylam==0
            indet(ipp,ith) = any(abs(some_eigs)>1);
        end
    end
end

boundary = NaN*thgrid;
for i=1:nth
    for j=1:npp-1
        if indet(j,i)~= indet(j+1,i)
            boundary(i) = (ppgrid(j)+ppgrid(j+1))/2;
        end
    end
end
figure()
area(thgrid,boundary,'FaceColor',[0.5 0.5 0.5])
axis([0.97 1.02 0.5 2])
text(0.98,3,'determinacy','Fontsize',15)
grid on
xlabel('\Theta')
ylabel('\Phi_{\pi}')
set(gcf, 'PaperPosition', [0 0 6 4]); 
set(gcf, 'PaperSize', [6 4]); 
saveas(gca,'det_lam097_6.pdf','pdf') 
saveas(gca,'det_lam097_6.eps','epsc') 

% Figure 3b) i.i.d income case

% parameters
param.gam = 3;
param.r = 0.04;
param.mu = param.r/(1+param.r);
param.kap = 0.1; % slope of phillips curve
param.thet = 1; % note, we can always find some dsigdy that generates this
param.sigss = 0.02; 0.1^2;
param.btil = 1-param.mu;
param.babylam = 0; % persistence of skill shock
param.lam = param.gam*(param.r/(1+param.r-param.babylam))*param.sigss;
param.truebeta = (1/(1+param.r))*exp(- param.sigss*(param.gam*param.r/(1+param.r-param.babylam))^2);


% make phipi and theta grids
npp = 800;
nth = 200;
ppgrid = linspace(0,2,npp);
thgrid = linspace(0.9,1.1,nth);
indet  = zeros(npp,nth);
for ipp = 1:npp
    for ith = 1:nth
        param.thet = thgrid(ith);
        param.phipi = ppgrid(ipp);
        some_eigs = eigs_noniid(param);
        if param.babylam>0
            indet(ipp,ith) = any(abs(some_eigs)<1);
        elseif param.babylam==0
            indet(ipp,ith) = any(abs(some_eigs)>1);
        end
    end
end

boundary = NaN*thgrid;
for i=1:nth
    for j=1:npp-1
        if indet(j,i)~= indet(j+1,i)
            boundary(i) = (ppgrid(j)+ppgrid(j+1))/2;
        end
    end
end
figure()
area(thgrid,boundary,'FaceColor',[0.5 0.5 0.5])
axis([0.9 1.1 0.5 2])
text(0.98,3,'determinacy','Fontsize',15)
grid on
xlabel('\Theta')
ylabel('\Phi_{\pi}')
set(gcf, 'PaperPosition', [0 0 6 4]); 
set(gcf, 'PaperSize', [6 4]); 
saveas(gca,'det_lam000_6.pdf','pdf') 
saveas(gca,'det_lam000_6.eps','epsc')

%% Figure 4 Forward guidance with persistent income risk

% Plot Figure 4a
