function [yhist,muhist,pihist] = solvepeg(param,ehist)
% solve for eqm consistent with given path of nominal interest rates
[~,T] = size(ehist);
T = T+1;
% think of the system as A x_t = B x_t+1 + C e_t or

%[1    0 0] Y_t  = [thet -lam 1/gam] Y_t+1  + [-1/gam 1/gam 1] i_t
%[0    1 0] mu_t = [0    btil -btil] mu_t+1 + [btil   0     0] rho_t
%[-kap 0 1] pi_t = [0    0    btil ] pi_t+1 + [0      0     0] (g_t - g_t+1)

gam = param.gam;
btil = param.btil;
thet = param.thet;
lam = param.lam;
kap = param.kap;

A = [[1 0 0];[0 1 0];[-kap 0 1]];
B = [[thet -lam 1/gam];[0 btil -btil];[0 0 btil]];
C = [[-1/gam 1/gam 1];[btil 0 0];[0 0 0]];

% easier to work with x_t = B2 x_t+1 + C2 e_t
B2 = inv(A)*B;
C2 = inv(A)*C;

xhist = zeros(3,T);

for k=1:T-1
    xhist(:,T-k) = B2*xhist(:,T-k+1) + C2*ehist(:,T-k);
end

yhist  = xhist(1,:);
muhist = xhist(2,:);
pihist = xhist(3,:);